@@ -292,6 +292,9 @@ class CompleteConfiguration(object):
     RUN_PASSING_TESTS_WITH_CRITERIA = [
 
     ]
+    
+    # list of test tool aliases for which we should not measure coverages
+    TESTCASE_TOOLALIASES_TO_SKIP_CRITERIA_COVERAGE = []
 
     CRITERIA_RESTRICTION_ENABLED = True  # Enable restricting mutation(scope)
 
@@ -388,6 +391,10 @@ class ToolUserCustom(dict):
     # analyzed program (target) in command line order POST_TARGET go after. 
     PRE_TARGET_CMD_ORDERED_FLAGS_LIST = None
     POST_TARGET_CMD_ORDERED_FLAGS_LIST = None
+    # Driver specific config. Helpful when a tool need to get data from another
+    # Or produce data for another (Example SEMu neding data from Mart)
+    # This should be defined in the tool as DriverConfig<Tool> class
+    DRIVER_CONFIG = None
 
     def __init__(self, **kwargs):
         for k in kwargs:
@@ -419,24 +426,48 @@ class TestcaseToolsConfig(BaseToolConfig):
     TESTS_ORACLE_OTHER_EXECUTABLE = None
 
     TEST_GENERATION_MAXTIME = 7200.0 # in seconds
+    # time givn by the framework before sending alt signal
+    TEST_GEN_TIMEOUT_FRAMEWORK_GRACE = 100 # in second
     ONE_TEST_EXECUTION_TIMEOUT = 60.0 # in seconds (Handle inifnite loops)
 
     # consider test execution error as a test failure
     TEST_EXECUTION_ERROR_AS_FAIL = False
     
+    # If the outlog is too big, we have MemoryError when 
+    # trying to load. Above this set limit, consider
+    # The log as oversized, as thought there is a 
+    # problem in the program.
+    # Default is 8 GB
+    OUTLOG_MAX_ALLOWED_BYTES_SIZE = 8 * (1024 ** 3) 
+    
+    # Scaling factor to apply on recorded test execution time before using
+    # as timeout on cosecutive executions
+    RECORDED_TEST_TIMEOUT_FACTOR = 5
+    
     def set_test_gen_maxtime(self, max_time):
         self.TEST_GENERATION_MAXTIME = max_time
+    def set_test_gen_timeout_framework_grace(self, grace_time):
+        self.TEST_GEN_TIMEOUT_FRAMEWORK_GRACE = grace_time
     def set_one_test_execution_timeout(self, timeout):
         self.ONE_TEST_EXECUTION_TIMEOUT = timeout
     def set_test_oracle_test(self, value):
         self.TESTS_ORACLE_TESTS = value
     def set_test_execution_error_as_failure(self, value):
         self.TEST_EXECUTION_ERROR_AS_FAIL = value
+    def set_outlog_max_allowed_bytes_size(self, value):
+        self.OUTLOG_MAX_ALLOWED_BYTES_SIZE = value
+    def set_recorded_test_timeout_factor(self, value):
+        self.RECORDED_TEST_TIMEOUT_FACTOR = value
 #~class TestcaseToolsConfig
     
 class CriteriaToolsConfig(BaseToolConfig):
     SEPARATED_TEST_EXECUTION_EXTRA_TIMEOUT_TIMES = 1.5 # proportion
     META_TEST_EXECUTION_EXTRA_TIMEOUT_TIMES = 100.0 # proportion
+    
+    def set_separated_test_execution_extra_timeout_times(self, timeout_times):
+        self.SEPARATED_TEST_EXECUTION_EXTRA_TIMEOUT_TIMES = timeout_times
+    def set_meta_test_execution_extra_timeout_times(self, timeout_times):
+        self.META_TEST_EXECUTION_EXTRA_TIMEOUT_TIMES = timeout_times
 #~class CriteriaToolsConfig
 
 
@@ -517,4 +548,4 @@ def save_common_default_template(filename=None):
 #~ def save_common_default_template()
 
 if __name__ == '__main__':
-    save_common_default_template()
\ No newline at end of file
+    save_common_default_template()
