@@ -66,7 +66,7 @@ class BaseTestcaseTool(abc.ABC):
         self.compress_test_storage_dir = True
 
         # Set Direct Arguments Variables
-        self.tests_working_dir = tests_working_dir
+        self.tests_working_dir = os.path.normpath(tests_working_dir)
         self.code_builds_factory = code_builds_factory
         self.config = config
         self.head_explorer = head_explorer
@@ -309,7 +309,8 @@ class BaseTestcaseTool(abc.ABC):
         # Record exec time if not existing
         if recalculate_execution_times:
             self.test_execution_time[testcase] = \
-                                        1 + int(time.time() - start_time)
+                                max(1, int(time.time() - start_time)) \
+                                    * self.config.RECORDED_TEST_TIMEOUT_FACTOR
 
         self._restore_env_vars()
         self._restore_default_executable(exe_path_map, env_vars, \
@@ -404,7 +405,8 @@ class BaseTestcaseTool(abc.ABC):
             with self.shared_loc:
                 if recalculate_execution_times:
                     self.test_execution_time[testcase] = \
-                                            1 + int(time.time() - start_time)
+                                     max(1, int(time.time() - start_time)) \
+                                 * self.config.RECORDED_TEST_TIMEOUT_FACTOR
 
                 test_failed_verdicts[testcase] = test_failed
                 test_outlog_hash[testcase] = execoutlog_hash
@@ -477,18 +479,27 @@ class BaseTestcaseTool(abc.ABC):
                                             collect_output=with_output_summary)
         if with_output_summary:
             retcode, outlog, timedout = output_err
-            outlog = self.code_builds_factory\
+            # case where the log exeeded the max alowed ytes size
+            if type(outlog) in (tuple, list):
+                ERROR_HANDLER.assert_true(len(outlog) == 2, \
+                    "Invalid tuple outlog. Expecting length followed by value",\
+                                                                      __file__)
+                out_len, out_hash_val = outlog
+            else:
+                outlog = self.code_builds_factory\
                                 .repository_manager\
                                 .get_test_exec_output_cleaner_func()(outlog)
-            out_len = len(outlog)
-            if hash_outlog:
-                outlog = outlog.encode('utf-8', 'backslashreplace')
-                out_hash_val = hashlib.sha512(outlog).hexdigest()
-            else:
-                out_hash_val = outlog
+                out_len = len(outlog)
+                if hash_outlog:
+                    outlog = outlog.encode('utf-8', 'backslashreplace')
+                    out_hash_val = hashlib.sha512(outlog).hexdigest()
+                else:
+                    out_hash_val = outlog
+
             outlog_summary = {
                 common_matrices.OutputLogData.OUTLOG_LEN: out_len,
-                common_matrices.OutputLogData.OUTLOG_HASH: out_hash_val,
+                common_matrices.OutputLogData.OUTLOG_HASH: \
+                                                    sys.intern(out_hash_val),
                 common_matrices.OutputLogData.RETURN_CODE: retcode,
                 common_matrices.OutputLogData.TIMEDOUT: timedout,
             }
@@ -585,7 +596,7 @@ class BaseTestcaseTool(abc.ABC):
                         os.chmod(os.path.join(root_, f_), 0o777)
         except PermissionError:
             ret,out,_ = DriversUtils.execute_and_get_retcode_out_err('sudo', \
-                                            ['chmod', '777', '-R', dirpath])
+                                    args_list=['chmod', '777', '-R', dirpath])
             ERROR_HANDLER.assert_true(ret == 0, \
                         "'sudo chmod 777 -R "+dirpath+"' failed (returned "+\
                                         str(ret)+"), error: "+out, __file__)
@@ -598,6 +609,12 @@ class BaseTestcaseTool(abc.ABC):
     def can_run_tests_in_parallel(self):
         return False
     #~ def can_run_tests_in_parallel()
+    
+    def get_test_format_class (self):
+        """ Can be useful for test fdupes
+        """
+        return None
+    # def get_test_format_class ()
 
     #######################################################################
     ##################### Methods to implement ############################
